from asset_inventory.models.server import Server
from asset_inventory.models.device import Device


class Inventory:

    def __init__(self, ip, server: Server, devices: [Device]):
        self.ip = ip
        self.server = server
        self.devices = devices

    def serialize(self):
        server_serialize = self.server.serialize()
        devices_serialize = [device.serialize() for device in self.devices]

        inventory_serialize = {component: value for component, value in server_serialize.items()}
        inventory_serialize.update({'devices': devices_serialize})

        return inventory_serialize



import asset_inventory

from os import path
from setuptools import setup


this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


CLASSIFIERS = [
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Operating System :: OS Independent',
]

setup(name='asset_inventory',
      version=asset_inventory.__version__,
      description=asset_inventory.__description__,
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='https://github.com/muhannadengineer/asset_inventory',
      author='Muhannad Alghamdi',
      author_email='muhannadengineer@gmail.com',
      license='MIT',
      packages=['asset_inventory', 'asset_inventory.models'],
      classifiers=CLASSIFIERS,
      keywords='ansible asset inventory',
      install_requires=['ansible', 'paramiko']
      )
